package Acme::CPANModules::Import::PerlDancerAdvent::2018_12_17;

our $DATE = '2018-12-30'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {description=>"This list is generated by extracting module names mentioned in [http://advent.perldancer.org/2018/17] (retrieved on 2018-12-30). Visit the URL for the full contents.",entries=>[{module=>"Dancer2::Plugin::Email"},{module=>"Email::Sender"},{module=>"Email::Sender::Transport::Redirect"},{module=>"HTML::FormatText::WithLinks"}],summary=>"Modules mentioned in Perl Dancer Advent Calendar 2018 (day 17)"};

1;
# ABSTRACT: Modules mentioned in Perl Dancer Advent Calendar 2018 (day 17)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlDancerAdvent::2018_12_17 - Modules mentioned in Perl Dancer Advent Calendar 2018 (day 17)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlDancerAdvent::2018_12_17 (from Perl distribution Acme-CPANModulesBundle-Import-PerlDancerAdvent-2018), released on 2018-12-30.

=head1 DESCRIPTION

This module is generated by extracting module names mentioned in L<http://advent.perldancer.org/2018/17> (retrieved on 2018-12-30). Visit the URL for the full contents.

Modules mentioned in Perl Dancer Advent Calendar 2018 (day 17).

This list is generated by extracting module names mentioned in [http://advent.perldancer.org/2018/17] (retrieved on 2018-12-30). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<Dancer2::Plugin::Email>

=item * L<Email::Sender>

=item * L<Email::Sender::Transport::Redirect>

=item * L<HTML::FormatText::WithLinks>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlDancerAdvent-2018>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlDancerAdvent-2018>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlDancerAdvent-2018>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
